package asm

import "bytes"

// Data represents the static read-only data.
type Data []byte

// Add adds the given bytes to the data block if this sequence of bytes doesn't exist yet.
// It returns the address relative to the start of the data section.
func (data *Data) Add(block []byte) Address {
	position := bytes.Index(*data, block)

	if position != -1 {
		return Address(position)
	}

	address := Address(len(*data))
	*data = append(*data, block...)
	return address
}
